@@ -1,20 +1,17 @@
-import logging
-
 from flowmaster.models import FlowItem, FlowStatus
 from flowmaster.operators.base.work import Work
-from flowmaster.operators.etl.policy import ETLFlowConfig
-from flowmaster.utils.logging_helper import CreateLogger
+from flowmaster.operators.etl.policy import ETLNotebook
+from flowmaster.utils.logging_helper import getLogger
 from flowmaster.utils.notifications import send_codex_telegram_message
 
 
 class BaseOperator:
-    def __init__(self, config: ETLFlowConfig, loglevel: int = logging.INFO):
-        self.loglevel = loglevel
-        self.config = config
-        self.name = config.name
+    def __init__(self, notebook: ETLNotebook):
+        self.notebook = notebook
+        self.name = notebook.name
 
-        self.logger = CreateLogger(self.name, level=logging.INFO)
-        self.Work = Work(config, self.logger)
+        self.logger = getLogger()
+        self.Work = Work(notebook, self.logger)
         self.Model = FlowItem  # TODO replace to Pydantic
 
     def send_notifications(self, status: FlowStatus.LiteralT, **kwargs):
@@ -23,11 +20,11 @@ class BaseOperator:
         for key, value in kwargs.items():
             message += f"\n{key}: {value}"
 
-        if self.config.work.notifications is None:
+        if self.notebook.work.notifications is None:
             return
 
         if status == FlowStatus.success:
-            codex_tg = self.config.work.notifications.codex_telegram
+            codex_tg = self.notebook.work.notifications.codex_telegram
 
             if codex_tg.on_success:
                 send_codex_telegram_message(codex_tg.links, message)
