@@ -1,7 +1,7 @@
 from pathlib import Path
 
 from flowmaster.operators.etl.loaders.csv.service import CSVLoader
-from flowmaster.operators.etl.policy import ETLFlowConfig
+from flowmaster.operators.etl.policy import ETLNotebook
 from flowmaster.operators.etl.providers import FakeDataProvider
 from flowmaster.operators.etl.providers.fakedata import FakeDataExportPolicy
 from tests import get_tests_dir
@@ -10,8 +10,8 @@ from tests.fixtures import work_policy, csv_load_policy, csv_transform_policy
 FILE_TESTS_DIR = get_tests_dir() / "__test_files__"
 Path.mkdir(FILE_TESTS_DIR, exist_ok=True)
 
-fakedata_to_csv_config = ETLFlowConfig(
-    name="fakedata_to_csv_config",
+fakedata_to_csv_notebook = ETLNotebook(
+    name="fakedata_to_csv_notebook",
     provider=FakeDataProvider.name,
     storage=CSVLoader.name,
     work=work_policy,
